<tr>
    <td style="padding: 24px;">
        <table role="presentation" width="100%" cellpadding="0" cellspacing="0" style="background-color: #FFFFFF; border-radius: 12px; box-shadow: 0 1px 3px rgba(0, 0, 0, 0.08);">
            <tr>
                <td style="padding: 20px 24px; border-bottom: 1px solid #E2E8F0;">
                    <h2 style="margin: 0; color: #1E3A8A; font-size: 16px; font-weight: 600;">{{ section_title }}</h2>
                </td>
            </tr>
            {% for image in images %}
            <tr>
                <td style="padding: 16px 24px;">
                    <img src="cid:{{ image.cid }}" alt="{{ image.alt }}" style="width: 100%; max-width: 550px; height: auto; display: block; margin: 0 auto;" />
                </td>
            </tr>
            {% endfor %}
        </table>
    </td>
</tr>
