<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{{ date }} {{ title }}</title>
</head>
<body style="margin: 0; padding: 0; background-color: #F8FAFC; font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, sans-serif;">
    <table role="presentation" width="100%" cellpadding="0" cellspacing="0" style="max-width: 600px; margin: 0 auto;">
        <tr>
            <td style="background-color: #1E40AF; padding: 32px 24px; text-align: center;">
                <h1 style="margin: 0; color: #FFFFFF; font-size: 24px; font-weight: 700; letter-spacing: -0.5px;">{{ date }} {{ title }}</h1>
            </td>
        </tr>
        
        {% for section in sections %}
        {{ section|safe }}
        {% endfor %}
        
        <tr>
            <td style="padding: 24px; text-align: center;">
                <p style="margin: 0; color: #94A3B8; font-size: 12px;">Generated by MXBIFlow Training System</p>
            </td>
        </tr>
    </table>
</body>
</html>
